pub trait MultiSliceArg<'a, A, D>where
A: 'a,
D: Dimension,{
type Output;
// Required method
fn multi_slice_move(&self, view: ArrayViewMut<'a, A, D>) -> Self::Output;
}Expand description
Slicing information describing multiple mutable, disjoint slices.
It’s unfortunate that we need 'a and A to be parameters of the trait,
but they’re necessary until Rust supports generic associated types.
Required Associated Types
Required Methods
Sourcefn multi_slice_move(&self, view: ArrayViewMut<'a, A, D>) -> Self::Output
fn multi_slice_move(&self, view: ArrayViewMut<'a, A, D>) -> Self::Output
Split the view into multiple disjoint slices.
Panics if performing any individual slice panics or if the slices are not disjoint (i.e. if they intersect).
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".